@@ -25,7 +25,10 @@ import java.io.DataOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.LinkedHashMap;
+import java.util.List;
 import java.util.Map;
 
 import javax.jcr.RepositoryException;
@@ -42,6 +45,7 @@ import org.apache.jackrabbit.core.persistence.util.BLOBStore;
 import org.apache.jackrabbit.core.persistence.util.BundleBinding;
 import org.apache.jackrabbit.core.persistence.util.ErrorHandling;
 import org.apache.jackrabbit.core.persistence.util.FileSystemBLOBStore;
+import org.apache.jackrabbit.core.persistence.util.NodeInfo;
 import org.apache.jackrabbit.core.persistence.util.NodePropBundle;
 import org.apache.jackrabbit.core.persistence.util.Serializer;
 import org.apache.jackrabbit.core.state.ItemStateException;
@@ -55,7 +59,7 @@ import org.slf4j.LoggerFactory;
  * <code>PersistenceManager</code> for Jackrabbit that keeps all data in memory
  * and that is capable of storing and loading its contents using a simple custom
  * binary serialization format (see {@link Serializer}).
- * <p/>
+ * <p>
  * It is configured through the following properties:
  * <ul>
  * <li><code>initialCapacity</code>: initial capacity of the hash map used to store the data</li>
@@ -68,7 +72,7 @@ import org.slf4j.LoggerFactory;
  * <li><code>minBlobSize</code> use blob store for binaries properties larger 
  * than minBlobSite (bytes). Default is 4096.</li>
  * </ul>
- * <p/>
+ * <p>
  * <b>Please note that this class should only be used for testing purposes.</b>
  *
  */
@@ -380,7 +384,7 @@ public class InMemBundlePersistenceManager extends AbstractBundlePersistenceMana
         }
         super.init(context);
         // initialize mem stores
-        bundleStore = new HashMap<NodeId, byte[]>(initialCapacity, loadFactor);
+        bundleStore = new LinkedHashMap<NodeId, byte[]>(initialCapacity, loadFactor);
         refsStore = new HashMap<NodeId, byte[]>(initialCapacity, loadFactor);
 
         // Choose a FileSystem for the BlobStore based on whether data is persistent or not 
@@ -489,9 +493,21 @@ public class InMemBundlePersistenceManager extends AbstractBundlePersistenceMana
     /**
      * {@inheritDoc}
      */
-    public Iterable<NodeId> getAllNodeIds(NodeId after, int maxCount) throws ItemStateException, RepositoryException {
-        // ignore after and count parameters.
-        return bundleStore.keySet();
+    public List<NodeId> getAllNodeIds(NodeId after, int maxCount) throws ItemStateException, RepositoryException {
+        final List<NodeId> result = new ArrayList<NodeId>();
+        boolean add = after == null;
+        int count = 0;
+        for (NodeId nodeId : bundleStore.keySet()) {
+            if (add) {
+                result.add(nodeId);
+                if (++count == maxCount) {
+                    break;
+                }
+            } else {
+                add = nodeId.equals(after);
+            }
+        }
+        return result;
     }
 
     /**
